@@ -65,6 +65,18 @@ class Course(models.Model):
             return None
         return schedule
     
+    def get_activity_today(self):
+        return Tracker.objects.filter(course=self,
+                                      tracker_date__day=datetime.datetime.now().day,
+                                      tracker_date__month=datetime.datetime.now().month,
+                                      tracker_date__year=datetime.datetime.now().year).count()
+       
+    def get_activity_week(self):
+        now = datetime.datetime.now()
+        last_week = datetime.datetime(now.year, now.month, now.day) - datetime.timedelta(days=7)
+        return Tracker.objects.filter(course=self,
+                                      tracker_date__gte=last_week).count()
+    
 class Tag(models.Model):
     name = models.TextField(blank=False)
     created_date = models.DateTimeField('date created',default=datetime.datetime.now)
